@@ -13,7 +13,7 @@
 #'
 #' @param verbose \code{logical} whether to provide details of downloading.
 #'
-#' @param pause Positive \code{integer} or integer \code{numeric} seconds for pausing during steps around unzipping that require time delayment. 
+#' @param pause Positive \code{integer} or integer \code{numeric} seconds for pausing during steps around unzipping that require time delayment.
 #'
 #' @param timeout Positive \code{integer} or integer \code{numeric} seconds for timeout on downloads. Temporarily overrides the \code{"timeout"} option in \code{\link[base]{options}}.
 #'
@@ -26,7 +26,7 @@
 #' @export
 #'
 download_observations <- function (path    = get_default_data_path(),
-                                   version = "latest", 
+                                   version = "latest",
                                    source  = "github",
                                    quiet   = FALSE,
                                    verbose = FALSE,
@@ -35,31 +35,34 @@ download_observations <- function (path    = get_default_data_path(),
                                    force   = FALSE) {
 
   return_if_null(x = version)
+  latest_requested <- identical(version, "latest")
 
   timeout_backup <- getOption("timeout")
   on.exit(options(timeout = timeout_backup))
-  options(timeout = timeout) 
+  options(timeout = timeout)
 
   if (source == "zenodo") {
 
-    base_url <- "https://zenodo.org/api/records/" 
+    base_url <- "https://zenodo.org/api/records/"
 
     got <- GET(base_url, query = list(q = "conceptrecid:1215988",
-                                      size = 9999, 
+                                      size = 9999,
                                       all_versions = "true"))
 
     stop_for_status(got, task = paste0("locate Zenodo concept record"))
 
-    contents <- content(got)    
+    contents <- content(got)
+    hits=getElement(contents, name = "hits")
+    hits=getElement(hits, name = "hits")
 
-    metadata <- lapply(FUN = getElement, 
-                       X = contents, 
+    metadata <- lapply(FUN = getElement,
+                       X = hits,
                        name = "metadata")
-    versions <- sapply(FUN = getElement, 
-                       X = metadata, 
+    versions <- sapply(FUN = getElement,
+                       X = metadata,
                        name = "version")
-    pub_date <- sapply(FUN = getElement, 
-                       X = metadata, 
+    pub_date <- sapply(FUN = getElement,
+                       X = metadata,
                        name = "publication_date")
 
     selected <- ifelse(version == "latest",
@@ -69,17 +72,17 @@ download_observations <- function (path    = get_default_data_path(),
     if (length(selected) == 0){
 
       stop(paste0("Failed to locate version `", version, "`"))
-   
+
     }
-    
-    zipball_url <- contents[[selected]]$files[[1]]$links$download     
-    version <- ifelse(version == "latest", 
+
+    zipball_url <- hits[[selected]]$files[[1]]$links$self
+    version <- ifelse(version == "latest",
                       metadata[[selected]]$version, version)
 
   } else if (source == "github") {
 
-    base_url <- "https://api.github.com/repos/weecology/PortalData/releases/" 
-    url <- ifelse(version == "latest", 
+    base_url <- "https://api.github.com/repos/weecology/PortalData/releases/"
+    url <- ifelse(version == "latest",
                   paste0(base_url, "latest"),
                   paste0(base_url, "tags/", version))
 
@@ -87,8 +90,8 @@ download_observations <- function (path    = get_default_data_path(),
 
     stop_for_status(got, task = paste0("locate version `", version, "`"))
 
-    zipball_url <- content(got)$zipball_url      
- 
+    zipball_url <- content(got)$zipball_url
+
     version <- ifelse(version == "latest", content(got)$name, version)
 
   } else {
@@ -96,7 +99,7 @@ download_observations <- function (path    = get_default_data_path(),
     stop("`source` must be either 'zenodo' or 'github'")
 
   }
-  
+
 
   temp <- file.path(tempdir(), "PortalData.zip")
   final <- file.path(path, "PortalData")
@@ -104,15 +107,17 @@ download_observations <- function (path    = get_default_data_path(),
 
   if (!force & file.exists(version_file)) {
 
-    existing_version <- scan(file  = version_file, 
-                             what  = character(), 
+    existing_version <- scan(file  = version_file,
+                             what  = character(),
                              quiet = TRUE)
-  
+
 
     if (existing_version == version) {
 
-      if (!quiet) {
-        message("Existing local version is up-to-date with remote version (", version, ") requested and `force` is FALSE, download is skipped")
+      # Avoid showing message in test (except if latest version is requested)
+      # use rlang::local_interactive() to simulate this message in non-interactive session.
+      if (!quiet && (rlang::is_interactive() || latest_requested)) {
+    	message("Existing local version is up-to-date with remote version (", version, ") requested and `force` is FALSE, download is skipped")
       }
 
       return(invisible())
@@ -120,17 +125,18 @@ download_observations <- function (path    = get_default_data_path(),
     }
 
   }
-
-  if (!quiet) {
+  # Avoid showing message in test (inform of version if latest is requested)
+  # use rlang::local_interactive() to simulate this message in non-interactive session.
+  if (!quiet && (rlang::is_interactive() || latest_requested)) {
     message("Downloading version `", version, "` of the data...")
   }
 
 
 
   result <- tryCatch(
-              expr  = download.file(url      = zipball_url, 
-                                    destfile = temp, 
-                                    quiet    = !verbose, 
+              expr  = download.file(url      = zipball_url,
+                                    destfile = temp,
+                                    quiet    = !verbose,
                                     mode     = "wb"),
               error = function(x){NA})
 
@@ -152,7 +158,7 @@ download_observations <- function (path    = get_default_data_path(),
 
     file.remove(old_files)
 
-    unlink(x         = final, 
+    unlink(x         = final,
            recursive = TRUE)
 
   }
@@ -192,7 +198,7 @@ check_for_newer_data <- function (path = get_default_data_path()) {
   }
 
 
-  url <- "https://api.github.com/repos/weecology/PortalData/releases/latest" 
+  url <- "https://api.github.com/repos/weecology/PortalData/releases/latest"
   got <- tryCatch(GET(url),
                   error = function(e) NULL)
   return_if_null(x = got, value = FALSE)
@@ -244,12 +250,14 @@ check_default_data_path <- function(ENV_VAR = "PORTALR_DATA_PATH",
 {
   if (is.na(get_default_data_path(fallback = NA, ENV_VAR)))
   {
-    MESSAGE_FUN("You don't appear to have a defined location for storing ", DATA_NAME, ".")
-    MESSAGE_FUN(format_todo(" Call ",
-                            format_code('use_default_data_path(\"<path>\")'),
-                            " if you wish to set the default data path."))
-    MESSAGE_FUN(DATA_NAME, " will be downloaded into ",
-                format_code(path.expand("~")), " otherwise.")
+  	msg <- cli::format_message(
+  		c(
+  			"You don't appear to have a defined location for storing {DATA_NAME}.",
+  			"i" = "Call {.code use_default_data_path(\"path\")} if you wish to set the default data path.",
+  			"i" = "{DATA_NAME} will be downloaded into {.path {path.expand('~')}} otherwise."
+  		)
+  	)
+  	MESSAGE_FUN(msg)
     return(FALSE)
   }
   return(TRUE)
@@ -309,14 +317,17 @@ use_default_data_path <- function(path = NULL, ENV_VAR = "PORTALR_DATA_PATH")
 
   # display message and copy new path setting to clipboard
   path_setting_string <- paste0(ENV_VAR, "=", '"', path, '"')
-  message(format_todo("Call ", format_code('usethis::edit_r_environ()'), " to open ",
-               format_value('.Renviron')))
-  message(format_todo("Store your data path with a line like:"))
-  message("  ", format_code(path_setting_string))
+  cli::cli_inform(c(
+    "*" = "Call {.run usethis::edit_r_environ()} to open {.val .Renviron}.",
+    "*" = "Store your data path with a line like:",
+    " " = path_setting_string
+  ))
   if (rlang::is_interactive() && clipr::clipr_available()) {
     clipr::write_clip(path_setting_string)
-    message("  [Copied to clipboard]")
+    cli::cli_inform("  [Copied to clipboard]")
   }
-  message(format_todo("Make sure ", format_value('.Renviron'), " ends with a newline!"))
+  cli::cli_inform(c(
+      "*" = "Make sure {.val .Renviron} ends with a newline!"
+  ))
   return()
 }
